@@ -1,11 +1,17 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2019, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2022, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
+const ExtensionUtils = imports.misc.extensionUtils;
+const Me = ExtensionUtils.getCurrentExtension();
+const _ = ExtensionUtils.gettext;
+
 const { GLib, GObject, GPaste, St } = imports.gi;
 
+const ActionButtonActor = Me.imports.actionButtonActor;
+
 var GPasteEmptyHistoryItem = GObject.registerClass(
 class GPasteEmptyHistoryItem extends St.Button {
     _init(client, settings, menu) {
@@ -15,11 +21,10 @@ class GPasteEmptyHistoryItem extends St.Button {
             reactive: true,
             can_focus: true,
             track_hover: true,
-            style_class: 'system-menu-action'
+            style_class: 'button',
+            child: new ActionButtonActor.GPasteActionButtonActor('edit-clear-all-symbolic', _("Empty history"))
         });
 
-        this.child = new St.Icon({ icon_name: 'edit-clear-all-symbolic' });
-
         this.connect('clicked', function() {
             menu.itemActivated();
             client.get_history_name((client, result) => {
